==> RsSmw-4.90.49.49-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Gbas/Setting.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setting:
	"""Setting commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("setting", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.gbas.setting.get_catalog() \n
		Queries the files with GBAS settings in the default directory. Listed are files with the file extension *.gbas. Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and
		specific directories. \n
			:return: catalog: filename1,filename2,... Returns a string of file names separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:DELete \n
		Snippet: driver.source.bb.gbas.setting.delete(filename = '1') \n
		Deletes the selected file from the default or specified directory. Deleted are files with the file extension *.gbas.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and specific directories. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:SETTing:DELete {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:LOAD \n
		Snippet: driver.source.bb.gbas.setting.load(filename = '1') \n
		Loads the selected file from the default or the specified directory. Load files with extension *.gbas.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and specific directories. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:SETTing:LOAD {param}')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:STORe \n
		Snippet: driver.source.bb.gbas.setting.set_store(filename = '1') \n
		Saves the current settings into the selected file; the file extensions *.gbas is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and specific directories. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:SETTing:STORe {param}')

==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Gbas/Setting.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setting:
	"""Setting commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("setting", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.gbas.setting.get_catalog() \n
		Queries the files with GBAS settings in the default directory. Listed are files with the file extension *.gbas. Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and
		specific directories. \n
			:return: catalog: filename1,filename2,... Returns a string of file names separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:DELete \n
		Snippet: driver.source.bb.gbas.setting.delete(filename = '1') \n
		Deletes the selected file from the default or specified directory. Deleted are files with the file extension *.gbas.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and specific directories. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:SETTing:DELete {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:LOAD \n
		Snippet: driver.source.bb.gbas.setting.load(filename = '1') \n
		Loads the selected file from the default or the specified directory. Load files with extension *.gbas.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and specific directories. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:SETTing:LOAD {param}')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SETTing:STORe \n
		Snippet: driver.source.bb.gbas.setting.set_store(filename = '1') \n
		Saves the current settings into the selected file; the file extensions *.gbas is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and specific directories. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:SETTing:STORe {param}')
